# author: Theophanis Tsandilas

# This is the same as IQ-tests-analysis-bonferroni.R
# But I also plot the actual datapoints together with the CIs
# author: Theophanis Tsandilas
rm(list=ls())
library(plotrix)

# IQ scores for 20 participants in each group
# G1: No music, G2: Classical, G3: Rock
G1 <- c(102, 97, 90, 107, 89, 104, 101, 112, 86, 108, 113, 94, 80, 98, 101, 107, 103, 111, 93, 99)
G2 <- c(112, 100, 86, 115, 94, 100, 112, 117, 95, 99, 89, 108, 97, 104, 109, 102, 100, 95, 99, 107)
G3 <- c(105, 83, 92, 106, 98, 86, 103, 87, 97, 103, 83, 90, 105, 79, 100, 96, 97, 105, 95, 99)

# calculate the means
mean.G1 <- mean(G1)
mean.G2 <- mean(G2)
mean.G3 <- mean(G3)

# construct individual CIs
ci.G1 <- t.test(G1)$conf.int
ci.G2 <- t.test(G2)$conf.int
ci.G3 <- t.test(G3)$conf.int

# construct the CI of all three pairwise differences
ci.G12 <- t.test(G1, G2)$conf.int
ci.G13 <- t.test(G1, G3)$conf.int
ci.G23 <- t.test(G2, G3)$conf.int

# construct the CI of all three pairwise differences with Bonferroni's correction
ci.G12.bonf <- t.test(G1, G2, conf.level = 0.9833)$conf.int
ci.G13.bonf <- t.test(G1, G3, conf.level = 0.9833)$conf.int
ci.G23.bonf <- t.test(G2, G3, conf.level = 0.9833)$conf.int

# plot the CIs
par(mfrow=c(1,2), mar = c(4,4,1,1), pty='s', cex.main = 1.1)

plotCI(c(1,2,3), c(mean.G1, mean.G2, mean.G3), ui=c(ci.G1[2], ci.G2[2], ci.G3[2]), li=c(ci.G1[1], ci.G2[1], ci.G3[1]), pch=5, xlab=NA, xaxt='n', xlim=c(.5, 3.5), ylab="IQ Score", lwd = 1.5, sfrac = 0, ylim=c(min(c(G1,G2,G3)), max(c(G1,G2,G3))))
par(new=TRUE) #Overlplot individual data points
plot(x=c(rep(1.1,length(G1)), rep(2.1,length(G2)), rep(3.1,length(G3))), y=c(G1, G2, G3), ylab=NA, xlab=NA, xaxt='n', yaxt='n', xlim=c(.5, 3.5), pch=1, col="grey", ylim=c(min(c(G1,G2,G3)), max(c(G1,G2,G3))))
axis(1, at = 1:3, labels = c("No Music", "Classic", "Rock"))

#First plot the corrected CIs in blue
plotCI(c(1,2,3), c(mean.G1 - mean.G2, mean.G1 - mean.G3, mean.G2 - mean.G3), ui=c(ci.G12.bonf[2], ci.G13.bonf[2], ci.G23.bonf[2]), li=c(ci.G12.bonf[1], ci.G13.bonf[1], ci.G23.bonf[1]), pch=NA, xlab=NA, xaxt='n', ylim=c(-10, 14), xlim=c(.5, 3.5), ylab="Diff IQ Score", lwd = 1.2, sfrac = 0.01, col = "red")

#Then, overplot the uncorrected ones in grey
par(new=TRUE)
plotCI(c(1,2,3), c(mean.G1 - mean.G2, mean.G1 - mean.G3, mean.G2 - mean.G3), ui=c(ci.G12[2], ci.G13[2], ci.G23[2]), li=c(ci.G12[1], ci.G13[1], ci.G23[1]), pch=5, xlab=NA, xaxt='n', ylim=c(-10, 14), xlim=c(.5, 3.5), ylab=NA, lwd = 1.5, sfrac = 0)

axis(1, at = 1:3, labels = c("No-Classic", "No-Rock", "Classic-Rock"))
segments(0, 0, 4, 0, lty=2)
