# author: Theophanis Tsandilas

# Script demonstrating how to calculate p values from the t distribution
#author: Theophanis Tsandilas

m0 <- 100 # mean for null hypothesis

# These are the observed IQ scores
scores <- c(90, 109, 93, 103, 101, 88, 98, 100, 87, 83, 97, 105, 99, 94, 81)
n <- length(scores)
m <- mean(scores)

# I estimate the standard error of the mean
se <- sd(scores) / sqrt(n)

# I calculate the t statistic, i.e., the standardized mean difference
t = -abs(m - m0) / se

# This is the two-sided p value, calculated from the cumulative density function of the t ditribution
pvalue <- 2*pt(t, n - 1)
cat("two sided p-value =", pvalue, "\n")


# This part is used to graphcally show how to calculate p values
# Show the graphs in a 1x2 grid
par(mfrow=c(1,2), mar = c(4,4,1,1), pty='s', cex.main = 1.1)

# I plot the t distribution and show the show the area that represents the p value
# See: https://www.r-bloggers.com/creating-shaded-areas-in-r/
seq.1 <- seq(-4, t, 0.01)
cord.x1 <- c(-4, seq.1, t)
cord.y1 <- c(0, dt(seq.1, n - 1), 0)

seq.2 <- seq(-t, 4, 0.01)
cord.x2 <- c(-t, seq.2, 4)
cord.y2 <- c(0, dt(seq.2, n - 1), 0)

curve(dt(x, n - 1), xlim=c(-4, 4), main='t distribution (pdf)')
polygon(cord.x1,cord.y1, col='red')
polygon(cord.x2,cord.y2, col='red')

# I plot the cdf of the t distribution and show the calculation of the p-value
curve(pt(x, n - 1), xlim = c(-4, 4), main='t distribution (cdf)')
y1 = pvalue/2
y2 = 1 - pvalue/2
segments(c(t,-t), c(-1,-1), c(t,-t), c(y1,y2), lty = 2, col ="red")
segments(c(-5,-5), c(y1,y2), c(t,-t), c(y1,y2), lty = 2, col ="red")
